@@ -9,6 +9,7 @@ from .request import SAFRSRequest
 from .response import SAFRSResponse
 from .json_encoder import SAFRSJSONEncoder
 from .jsonapi_filters import FilteringStrategy
+from functools import wraps
 
 
 class SAFRS:
@@ -18,7 +19,7 @@ class SAFRS:
     :param LOGLEVEL: loglevel configuration variable, values from logging module (0: trace, .. 50: critical)
     """
 
-    # Configuration settings, these can be overridden in config.py
+    # Configuration settings are stored as class variables
     MAX_PAGE_LIMIT = 250
     MAX_PAGE_OFFSET = 2 ** 31
     ENABLE_RELATIONSHIPS = True
@@ -39,6 +40,8 @@ class SAFRS:
     config = {}
     filtering_strategy = FilteringStrategy()
 
+    OPTIMIZED_LOADING = True
+
     def __init__(self, app, *args, **kwargs):
         """
         Constructor
@@ -53,7 +56,7 @@ class SAFRS:
         """
         API and application initialization
         """
-        if not isinstance(app, Flask):
+        if not isinstance(app, Flask):  # pragma: no cover
             raise TypeError("'app' should be Flask.")
 
         if app_db is None:
@@ -76,12 +79,10 @@ class SAFRS:
             swaggerui_blueprint.json_encoder = JSONEncoder
 
         for conf_name, conf_val in kwargs.items():
-            setattr(self, conf_name, conf_val)
+            setattr(SAFRS, conf_name, conf_val)
 
         for conf_name, conf_val in app.config.items():
-            setattr(self, conf_name, conf_val)
-
-        self.config.update(app.config)
+            setattr(SAFRS, conf_name, conf_val)
 
         @app.before_request
         def handle_invalid_usage():
@@ -89,7 +90,8 @@ class SAFRS:
 
         @app.before_request
         def init_ja_data():
-            # ja_data holds all data[] that will be encoded
+            # ja_data holds all data[] instances that will be encoded
+            # ja_included holds all included instances
             g.ja_data = set()
             g.ja_included = set()
 
@@ -132,17 +134,17 @@ def dict_merge(dct, merge_dct):
             dct[str(k)] = merge_dct[k]
 
 
-def test_decorator(func):
+def test_decorator(func):  # pragma: no cover
     """Example flask-restful decorator that can be used in the "decorators" Api argument
     cfr. https://flask-restful.readthedocs.io/en/latest/api.html#id1
     """
 
+    @wraps(func)
     def api_wrapper(*args, **kwargs):
         return func(*args, **kwargs)
 
-    if func.__name__.lower() == "get":  # pragma : no cover
+    if func.__name__.lower() == "get":
         result = api_wrapper
-        result.__name__ = func.__name__  # make sure to to reset the __name__ !
         return result
 
     return func
@@ -156,7 +158,7 @@ DB = SQLAlchemy()
 try:
     DEBUG = os.getenv("DEBUG", logging.WARNING)
     LOGLEVEL = int(DEBUG)
-except ValueError:  # pragma : no cover
+except ValueError:  # pragma: no cover
     print('Invalid LogLevel in DEBUG Environment Variable! "{}"'.format(DEBUG))
     LOGLEVEL = logging.INFO
 
