@@ -264,9 +264,10 @@ def get_swagger_doc_arguments(cls, method_name, http_method):
     else:
         raise SystemValidationError("method {} not found".format(method_name))
 
+    f_args = inspect.getfullargspec(method).args
     rest_doc = get_doc(method)
     description = rest_doc.get("description", "")
-    if rest_doc:
+    if rest_doc is not None:
         method_args = rest_doc.get("args", [])  # jsonapi_rpc "POST" method arguments
         parameters = rest_doc.get("parameters", [])  # query string parameters
         if method_args and isinstance(method_args, dict):
@@ -276,7 +277,13 @@ def get_swagger_doc_arguments(cls, method_name, http_method):
                 """
                 model_name = "{}_{}".format(cls.__name__, method_name)
                 method_field = {"method": method_name, "args": method_args}
-                fields["meta"] = schema_from_object(model_name, method_field)
+                if getattr(method, "valid_jsonapi", True):
+                    payload = schema_from_object(model_name, method_field)
+                    fields["meta"] = payload
+                else:
+                    # todo: maybe get function args from inspect
+                    for k, v in method_args.items():
+                        fields[k] =  {"example": v }
         if rest_doc.get(PAGEABLE):
             parameters += default_paging_parameters()
         if rest_doc.get(FILTERABLE):
@@ -296,12 +303,11 @@ def get_swagger_doc_arguments(cls, method_name, http_method):
                         "description": description,
                     }
                     parameters += param
-    elif http_method != "options":
+    elif f_args and http_method != "options":
         safrs.log.warning('No documentation for method "{}"'.format(method_name))
         # jsonapi_rpc method has no documentation, generate it w/ inspect
-        f_args = inspect.getfullargspec(method).args
         f_defaults = inspect.getfullargspec(method).defaults or []
-        if f_args[0] in ("cls", "self"):
+        if f_args and f_args[0] in ("cls", "self"):
             f_args = f_args[1:]
         args = dict(zip(f_args, f_defaults))
         model_name = "{}_{}".format(cls.__name__, method_name)
